[binutils-gdb] s390: Mention GOTIE20 relocation in TLS related comment

Jens Remus jremus@sourceware.org
Fri Nov 14 08:53:07 GMT 2025


https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=169341f282b3de603666f1e55451600541f372e8

commit 169341f282b3de603666f1e55451600541f372e8
Author: Jens Remus <jremus@linux.ibm.com>
Date:   Fri Nov 14 09:42:13 2025 +0100

    s390: Mention GOTIE20 relocation in TLS related comment
    
    Commit bd1ea41b84b0 introduced the R_390_TLS_GOTIE20 relocation, but
    missed to update a comment that mentions the related R_390_TLS_GOTIE12
    relocation.
    
    bfd/
            * elf32-s390.c (allocate_dynrelocs): Mention GOTIE20 relocation
            in TLS related comment.
            * elf64-s390.c (allocate_dynrelocs): Likewise.
    
    Signed-off-by: Jens Remus <jremus@linux.ibm.com>

Diff:
---
 bfd/elf32-s390.c | 4 ++--
 bfd/elf64-s390.c | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/bfd/elf32-s390.c b/bfd/elf32-s390.c
index ea5368ea9dd..252ec44f409 100644
--- a/bfd/elf32-s390.c
+++ b/bfd/elf32-s390.c
@@ -1624,9 +1624,9 @@ allocate_dynrelocs (struct elf_link_hash_entry *h, void * inf)
       elf_s390_adjust_gotplt((struct elf_s390_link_hash_entry *) h);
     }
 
   /* If R_390_TLS_{IE32,GOTIE32,GOTIE12,IEENT} symbol is now local to
      the binary, we can optimize a bit. IE32 and GOTIE32 get converted
-     to R_390_TLS_LE32 requiring no TLS entry. For GOTIE12 and IEENT
+     to R_390_TLS_LE32 requiring no TLS entry. For GOTIE12, GOTIE20, and IEENT
      we can save the dynamic TLS relocation.  */
   if (h->got.refcount > 0
       && !bfd_link_pic (info)
@@ -1624,9 +1624,9 @@ allocate_dynrelocs (struct elf_link_hash_entry *h, void * inf)
     }
 
-  /* If R_390_TLS_{IE32,GOTIE32,GOTIE12,IEENT} symbol is now local to
+  /* If R_390_TLS_{IE32,GOTIE32,GOTIE12,GOTIE20,IEENT} symbol is now local to
      the binary, we can optimize a bit. IE32 and GOTIE32 get converted
diff --git a/bfd/elf64-s390.c b/bfd/elf64-s390.c
index 9242407b1b5..6394f27e0e2 100644
--- a/bfd/elf64-s390.c
+++ b/bfd/elf64-s390.c
@@ -1776,9 +1776,9 @@ allocate_dynrelocs (struct elf_link_hash_entry *h,
       elf_s390_adjust_gotplt((struct elf_s390_link_hash_entry *) h);
     }
 
   /* If R_390_TLS_{IE64,GOTIE64,GOTIE12,IEENT} symbol is now local to
      the binary, we can optimize a bit. IE64 and GOTIE64 get converted
-     to R_390_TLS_LE64 requiring no TLS entry. For GOTIE12 and IEENT
+     to R_390_TLS_LE64 requiring no TLS entry. For GOTIE12, GOTIE20, and IEENT
      we can save the dynamic TLS relocation.  */
   if (h->got.refcount > 0
       && !bfd_link_dll (info)
@@ -1776,9 +1776,9 @@ allocate_dynrelocs (struct elf_link_hash_entry *h,
     }
 
-  /* If R_390_TLS_{IE64,GOTIE64,GOTIE12,IEENT} symbol is now local to
+  /* If R_390_TLS_{IE64,GOTIE64,GOTIE12,GOTIE20,IEENT} symbol is now local to
      the binary, we can optimize a bit. IE64 and GOTIE64 get converted


More information about the Binutils-cvs mailing list